@@ -1,19 +1,22 @@
-from django.conf.urls import patterns, url
+# -*- coding: utf-8 -*-
+from django.conf.urls import url
+
+from . import views
 
 
-urlpatterns = patterns('impersonate.views',
-    url(r'^(?P<uid>\d+)/$',
-        'impersonate',
-        name='impersonate-start'),
+urlpatterns = [
     url(r'^stop/$',
-        'stop_impersonate',
+        views.stop_impersonate,
         name='impersonate-stop'),
     url(r'^list/$',
-        'list_users',
+        views.list_users,
         {'template': 'impersonate/list_users.html'},
         name='impersonate-list'),
     url(r'^search/$',
-        'search_users',
+        views.search_users,
         {'template': 'impersonate/search_users.html'},
         name='impersonate-search'),
-)
+    url(r'^(?P<uid>.+)/$',
+        views.impersonate,
+        name='impersonate-start'),
+]
